# `deaddrops`
---

A simple python library to interact with the [dead drops website](https://deaddrops.com/) functionalities.

## Features

With this you can : 

- Get the dead drop database statistics and content ;
- Search through dead drop database content ;
- Sumbit a dead drop ;

## Installation

Install it with pip :

```
$ pip install deaddrops
```

## Usage

See the `docs/` README.md file to get the library documentation.

## Ideas and enhancements

If you have any idea to enhance this tool, please express them in the issue section.
